---
title: Dig 
description: Represents a command for an agent to dig rubble.
---

## Signature

```py
Dig()
```

## Description

Represents a command instructing the agent to dig from the current cell.  
This command will only succeed if the top layer of the cell is rubble.  

## Example

```py
top_layer = cell.get_top_layer()
if isinstance(top_layer, Rubble):
  agent.send(Dig())
```
